@@ -1,15 +1,13 @@
 use super::Optimizer;
-use crate::compress::optimize::Ctx;
-use crate::compress::util::negate_cost;
-use crate::debug::dump;
+use crate::{
+    compress::{optimize::Ctx, util::negate_cost},
+    debug::dump,
+};
 use swc_atoms::js_word;
 use swc_common::Spanned;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
-use swc_ecma_utils::ident::IdentLike;
-use swc_ecma_utils::Type;
-use swc_ecma_utils::Value::Known;
-use swc_ecma_utils::{undefined, ExprExt};
+use swc_ecma_utils::{ident::IdentLike, undefined, ExprExt, Type, Value::Known};
 
 /// Methods related to the options `bools` and `bool_as_ints`.
 impl Optimizer<'_> {
