@@ -3,9 +3,7 @@ use swc_atoms::js_word;
 use swc_common::Spanned;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
-use swc_ecma_utils::ident::IdentLike;
-use swc_ecma_utils::ExprExt;
-use swc_ecma_utils::Value::Known;
+use swc_ecma_utils::{ident::IdentLike, ExprExt, Value::Known};
 
 impl Optimizer<'_> {
     pub(super) fn optimize_expr_in_str_ctx_unsafely(&mut self, e: &mut Expr) {
