@@ -1,10 +1,12 @@
-use crate::analyzer::analyze;
-use crate::analyzer::ProgramData;
-use crate::option::ManglePropertiesOptions;
-use crate::util::base54::incr_base54;
+use crate::{
+    analyzer::{analyze, ProgramData},
+    option::ManglePropertiesOptions,
+    util::base54::incr_base54,
+};
 use once_cell::sync::Lazy;
-use std::collections::{HashMap, HashSet};
+use std::collections::HashSet;
 use swc_atoms::JsWord;
+use swc_common::collections::{AHashMap, AHashSet};
 use swc_ecma_ast::{
     CallExpr, Expr, ExprOrSuper, Ident, KeyValueProp, Lit, MemberExpr, Module, Prop, PropName, Str,
     StrKind,
@@ -12,14 +14,14 @@ use swc_ecma_ast::{
 use swc_ecma_utils::ident::IdentLike;
 use swc_ecma_visit::{VisitMut, VisitMutWith};
 
-pub static JS_ENVIRONMENT_PROPS: Lazy<HashSet<JsWord>> = Lazy::new(|| {
+pub static JS_ENVIRONMENT_PROPS: Lazy<AHashSet<JsWord>> = Lazy::new(|| {
     let domprops: Vec<JsWord> = serde_json::from_str(include_str!("../lists/domprops.json"))
         .expect("failed to parse domprops.json for property mangler");
 
     let jsprops: Vec<JsWord> = serde_json::from_str(include_str!("../lists/jsprops.json"))
         .expect("Failed to parse jsprops.json for property mangler");
 
-    let mut word_set: HashSet<JsWord> = HashSet::new();
+    let mut word_set: AHashSet<JsWord> = HashSet::default();
 
     for name in domprops.iter().chain(jsprops.iter()) {
         word_set.insert(name.clone());
@@ -32,11 +34,11 @@ pub static JS_ENVIRONMENT_PROPS: Lazy<HashSet<JsWord>> = Lazy::new(|| {
 struct ManglePropertiesState {
     options: ManglePropertiesOptions,
 
-    names_to_mangle: HashSet<JsWord>,
-    unmangleable: HashSet<JsWord>,
+    names_to_mangle: AHashSet<JsWord>,
+    unmangleable: AHashSet<JsWord>,
 
     // Cache of already mangled names
-    cache: HashMap<JsWord, JsWord>,
+    cache: AHashMap<JsWord, JsWord>,
 
     // Numbers to pass to base54()
     n: usize,
