@@ -4,4 +4,5 @@ pub mod global_defs;
 pub mod hygiene;
 pub mod mangle_names;
 pub mod mangle_props;
-pub mod single;
+pub mod postcompress;
+pub mod precompress;
